# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authorizer/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.authorizer import definition_pb2 as authorizer_dot_definition__pb2
from union.internal.common import authorization_pb2 as common_dot_authorization__pb2
from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.common import identity_pb2 as common_dot_identity__pb2
from union.internal.common import policy_pb2 as common_dot_policy__pb2
from union.internal.common import role_pb2 as common_dot_role__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61uthorizer/payload.proto\x12\x13\x63loudidl.authorizer\x1a\x1b\x61uthorizer/definition.proto\x1a\x1a\x63ommon/authorization.proto\x1a\x17\x63ommon/identifier.proto\x1a\x15\x63ommon/identity.proto\x1a\x13\x63ommon/policy.proto\x1a\x11\x63ommon/role.proto\x1a\x17validate/validate.proto\"\xfb\x01\n\x10\x41uthorizeRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12?\n\x08identity\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08identity\x12?\n\x08resource\x18\x03 \x01(\x0b\x32\x19.cloudidl.common.ResourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource\x12\x41\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32\x17.cloudidl.common.ActionB\x10\xfa\x42\r\x82\x01\n \x00 \x01 \x02 \x03 \x04R\x06\x61\x63tion\"-\n\x11\x41uthorizeResponse\x12\x18\n\x07\x61llowed\x18\x01 \x01(\x08R\x07\x61llowed\"|\n\x15\x43reateIdentityRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12?\n\x08identity\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08identity\"\x18\n\x16\x43reateIdentityResponse\"|\n\x15\x44\x65leteIdentityRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12?\n\x08identity\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08identity\"\x18\n\x16\x44\x65leteIdentityResponse\"\x8c\x02\n\x15\x41ssignIdentityRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12?\n\x08identity\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08identity\x12>\n\x07role_id\x18\x03 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x02\x18\x01H\x00R\x06roleId\x12@\n\tpolicy_id\x18\x04 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierH\x00R\x08policyIdB\x0c\n\nassignment\"\x18\n\x16\x41ssignIdentityResponse\"\x8a\x02\n\x17UnassignIdentityRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12?\n\x08identity\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08identity\x12:\n\x07role_id\x18\x03 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierH\x00R\x06roleId\x12@\n\tpolicy_id\x18\x04 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierH\x00R\x08policyIdB\x0c\n\nassignment\"\x1a\n\x18UnassignIdentityResponse\"\x83\x01\n\x1cGetIdentityAssignmentRequest\x12?\n\x08identity\x18\x01 \x01(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08identity\x12\"\n\x0corganization\x18\x02 \x01(\tR\x0corganization\"y\n\x1dGetIdentityAssignmentResponse\x12X\n\x13identity_assignment\x18\x01 \x01(\x0b\x32\'.cloudidl.authorizer.IdentityAssignmentR\x12identityAssignment\"\x89\x01\n\x1eListIdentityAssignmentsRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12\x43\n\nidentities\x18\x02 \x03(\x0b\x32\x19.cloudidl.common.IdentityB\x08\xfa\x42\x05\x92\x01\x02\x08\x01R\nidentities\"}\n\x1fListIdentityAssignmentsResponse\x12Z\n\x14identity_assignments\x18\x01 \x03(\x0b\x32\'.cloudidl.authorizer.IdentityAssignmentR\x13identityAssignments\"Y\n\x1aGetPolicyAssignmentRequest\x12;\n\x02id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"q\n\x1bGetPolicyAssignmentResponse\x12R\n\x11policy_assignment\x18\x01 \x01(\x0b\x32%.cloudidl.authorizer.PolicyAssignmentR\x10policyAssignment\"X\n\x15\x43reateResourceRequest\x12?\n\x08resource\x18\x01 \x01(\x0b\x32\x19.cloudidl.common.ResourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource\"\x18\n\x16\x43reateResourceResponse\"X\n\x15\x44\x65leteResourceRequest\x12?\n\x08resource\x18\x01 \x01(\x0b\x32\x19.cloudidl.common.ResourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource\"\x18\n\x16\x44\x65leteResourceResponse\"\xe8\x01\n\x19\x43reateOrganizationRequest\x12+\n\x0corganization\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0corganization\x12Z\n\x14identity_assignments\x18\x02 \x03(\x0b\x32\'.cloudidl.authorizer.IdentityAssignmentR\x13identityAssignments\x12\x42\n\x07options\x18\x10 \x01(\x0b\x32(.cloudidl.authorizer.OrganizationOptionsR\x07options\"\x1c\n\x1a\x43reateOrganizationResponse\"E\n\x16GetOrganizationRequest\x12+\n\x0corganization\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0corganization\"\x19\n\x17GetOrganizationResponse\"H\n\x19\x44\x65leteOrganizationRequest\x12+\n\x0corganization\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0corganization\"\x1c\n\x1a\x44\x65leteOrganizationResponse\"P\n\x13\x43reatePolicyRequest\x12\x39\n\x06policy\x18\x01 \x01(\x0b\x32\x17.cloudidl.common.PolicyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06policy\"\x16\n\x14\x43reatePolicyResponse\"O\n\x10GetPolicyRequest\x12;\n\x02id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"D\n\x11GetPolicyResponse\x12/\n\x06policy\x18\x01 \x01(\x0b\x32\x17.cloudidl.common.PolicyR\x06policy\"R\n\x13\x44\x65letePolicyRequest\x12;\n\x02id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"\x16\n\x14\x44\x65letePolicyResponse\"9\n\x13ListPoliciesRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\"K\n\x14ListPoliciesResponse\x12\x33\n\x08policies\x18\x01 \x03(\x0b\x32\x17.cloudidl.common.PolicyR\x08policies\"\xaa\x01\n\x1a\x43reatePolicyBindingRequest\x12H\n\tpolicy_id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08policyId\x12\x42\n\x07\x62inding\x18\x02 \x01(\x0b\x32\x1e.cloudidl.common.PolicyBindingB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07\x62inding\"\x1d\n\x1b\x43reatePolicyBindingResponse\"\xaa\x01\n\x1a\x44\x65letePolicyBindingRequest\x12H\n\tpolicy_id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08policyId\x12\x42\n\x07\x62inding\x18\x02 \x01(\x0b\x32\x1e.cloudidl.common.PolicyBindingB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07\x62inding\"\x1d\n\x1b\x44\x65letePolicyBindingResponse\"H\n\x11\x43reateRoleRequest\x12\x33\n\x04role\x18\x01 \x01(\x0b\x32\x15.cloudidl.common.RoleB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04role\"\x14\n\x12\x43reateRoleResponse\"K\n\x0eGetRoleRequest\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"<\n\x0fGetRoleResponse\x12)\n\x04role\x18\x01 \x01(\x0b\x32\x15.cloudidl.common.RoleR\x04role\"N\n\x11\x44\x65leteRoleRequest\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"\x14\n\x12\x44\x65leteRoleResponse\"6\n\x10ListRolesRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\"@\n\x11ListRolesResponse\x12+\n\x05roles\x18\x01 \x03(\x0b\x32\x15.cloudidl.common.RoleR\x05roles\"\x97\x01\n\x17\x43reateRoleActionRequest\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x41\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x17.cloudidl.common.ActionB\x10\xfa\x42\r\x82\x01\n \x00 \x01 \x02 \x03 \x04R\x06\x61\x63tion\"\x1a\n\x18\x43reateRoleActionResponse\"\x97\x01\n\x17\x44\x65leteRoleActionRequest\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x41\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x17.cloudidl.common.ActionB\x10\xfa\x42\r\x82\x01\n \x00 \x01 \x02 \x03 \x04R\x06\x61\x63tion\"\x1a\n\x18\x44\x65leteRoleActionResponseB\xc5\x01\n\x17\x63om.cloudidl.authorizerB\x0cPayloadProtoH\x02P\x01Z-github.com/unionai/cloud/gen/pb-go/authorizer\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43loudidl.Authorizer\xca\x02\x13\x43loudidl\\Authorizer\xe2\x02\x1f\x43loudidl\\Authorizer\\GPBMetadata\xea\x02\x14\x43loudidl::Authorizerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'authorizer.payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.cloudidl.authorizerB\014PayloadProtoH\002P\001Z-github.com/unionai/cloud/gen/pb-go/authorizer\242\002\003CAX\252\002\023Cloudidl.Authorizer\312\002\023Cloudidl\\Authorizer\342\002\037Cloudidl\\Authorizer\\GPBMetadata\352\002\024Cloudidl::Authorizer'
  _AUTHORIZEREQUEST.fields_by_name['identity']._options = None
  _AUTHORIZEREQUEST.fields_by_name['identity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AUTHORIZEREQUEST.fields_by_name['resource']._options = None
  _AUTHORIZEREQUEST.fields_by_name['resource']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AUTHORIZEREQUEST.fields_by_name['action']._options = None
  _AUTHORIZEREQUEST.fields_by_name['action']._serialized_options = b'\372B\r\202\001\n \000 \001 \002 \003 \004'
  _CREATEIDENTITYREQUEST.fields_by_name['identity']._options = None
  _CREATEIDENTITYREQUEST.fields_by_name['identity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEIDENTITYREQUEST.fields_by_name['identity']._options = None
  _DELETEIDENTITYREQUEST.fields_by_name['identity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ASSIGNIDENTITYREQUEST.fields_by_name['identity']._options = None
  _ASSIGNIDENTITYREQUEST.fields_by_name['identity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ASSIGNIDENTITYREQUEST.fields_by_name['role_id']._options = None
  _ASSIGNIDENTITYREQUEST.fields_by_name['role_id']._serialized_options = b'\030\001'
  _UNASSIGNIDENTITYREQUEST.fields_by_name['identity']._options = None
  _UNASSIGNIDENTITYREQUEST.fields_by_name['identity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETIDENTITYASSIGNMENTREQUEST.fields_by_name['identity']._options = None
  _GETIDENTITYASSIGNMENTREQUEST.fields_by_name['identity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTIDENTITYASSIGNMENTSREQUEST.fields_by_name['identities']._options = None
  _LISTIDENTITYASSIGNMENTSREQUEST.fields_by_name['identities']._serialized_options = b'\372B\005\222\001\002\010\001'
  _GETPOLICYASSIGNMENTREQUEST.fields_by_name['id']._options = None
  _GETPOLICYASSIGNMENTREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATERESOURCEREQUEST.fields_by_name['resource']._options = None
  _CREATERESOURCEREQUEST.fields_by_name['resource']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETERESOURCEREQUEST.fields_by_name['resource']._options = None
  _DELETERESOURCEREQUEST.fields_by_name['resource']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEORGANIZATIONREQUEST.fields_by_name['organization']._options = None
  _CREATEORGANIZATIONREQUEST.fields_by_name['organization']._serialized_options = b'\372B\004r\002\020\001'
  _GETORGANIZATIONREQUEST.fields_by_name['organization']._options = None
  _GETORGANIZATIONREQUEST.fields_by_name['organization']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEORGANIZATIONREQUEST.fields_by_name['organization']._options = None
  _DELETEORGANIZATIONREQUEST.fields_by_name['organization']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['policy']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['policy']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETPOLICYREQUEST.fields_by_name['id']._options = None
  _GETPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEPOLICYREQUEST.fields_by_name['id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPOLICYBINDINGREQUEST.fields_by_name['policy_id']._options = None
  _CREATEPOLICYBINDINGREQUEST.fields_by_name['policy_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPOLICYBINDINGREQUEST.fields_by_name['binding']._options = None
  _CREATEPOLICYBINDINGREQUEST.fields_by_name['binding']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEPOLICYBINDINGREQUEST.fields_by_name['policy_id']._options = None
  _DELETEPOLICYBINDINGREQUEST.fields_by_name['policy_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEPOLICYBINDINGREQUEST.fields_by_name['binding']._options = None
  _DELETEPOLICYBINDINGREQUEST.fields_by_name['binding']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEROLEREQUEST.fields_by_name['role']._options = None
  _CREATEROLEREQUEST.fields_by_name['role']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETROLEREQUEST.fields_by_name['id']._options = None
  _GETROLEREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEROLEREQUEST.fields_by_name['id']._options = None
  _DELETEROLEREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEROLEACTIONREQUEST.fields_by_name['id']._options = None
  _CREATEROLEACTIONREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEROLEACTIONREQUEST.fields_by_name['action']._options = None
  _CREATEROLEACTIONREQUEST.fields_by_name['action']._serialized_options = b'\372B\r\202\001\n \000 \001 \002 \003 \004'
  _DELETEROLEACTIONREQUEST.fields_by_name['id']._options = None
  _DELETEROLEACTIONREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEROLEACTIONREQUEST.fields_by_name['action']._options = None
  _DELETEROLEACTIONREQUEST.fields_by_name['action']._serialized_options = b'\372B\r\202\001\n \000 \001 \002 \003 \004'
  _globals['_AUTHORIZEREQUEST']._serialized_start=220
  _globals['_AUTHORIZEREQUEST']._serialized_end=471
  _globals['_AUTHORIZERESPONSE']._serialized_start=473
  _globals['_AUTHORIZERESPONSE']._serialized_end=518
  _globals['_CREATEIDENTITYREQUEST']._serialized_start=520
  _globals['_CREATEIDENTITYREQUEST']._serialized_end=644
  _globals['_CREATEIDENTITYRESPONSE']._serialized_start=646
  _globals['_CREATEIDENTITYRESPONSE']._serialized_end=670
  _globals['_DELETEIDENTITYREQUEST']._serialized_start=672
  _globals['_DELETEIDENTITYREQUEST']._serialized_end=796
  _globals['_DELETEIDENTITYRESPONSE']._serialized_start=798
  _globals['_DELETEIDENTITYRESPONSE']._serialized_end=822
  _globals['_ASSIGNIDENTITYREQUEST']._serialized_start=825
  _globals['_ASSIGNIDENTITYREQUEST']._serialized_end=1093
  _globals['_ASSIGNIDENTITYRESPONSE']._serialized_start=1095
  _globals['_ASSIGNIDENTITYRESPONSE']._serialized_end=1119
  _globals['_UNASSIGNIDENTITYREQUEST']._serialized_start=1122
  _globals['_UNASSIGNIDENTITYREQUEST']._serialized_end=1388
  _globals['_UNASSIGNIDENTITYRESPONSE']._serialized_start=1390
  _globals['_UNASSIGNIDENTITYRESPONSE']._serialized_end=1416
  _globals['_GETIDENTITYASSIGNMENTREQUEST']._serialized_start=1419
  _globals['_GETIDENTITYASSIGNMENTREQUEST']._serialized_end=1550
  _globals['_GETIDENTITYASSIGNMENTRESPONSE']._serialized_start=1552
  _globals['_GETIDENTITYASSIGNMENTRESPONSE']._serialized_end=1673
  _globals['_LISTIDENTITYASSIGNMENTSREQUEST']._serialized_start=1676
  _globals['_LISTIDENTITYASSIGNMENTSREQUEST']._serialized_end=1813
  _globals['_LISTIDENTITYASSIGNMENTSRESPONSE']._serialized_start=1815
  _globals['_LISTIDENTITYASSIGNMENTSRESPONSE']._serialized_end=1940
  _globals['_GETPOLICYASSIGNMENTREQUEST']._serialized_start=1942
  _globals['_GETPOLICYASSIGNMENTREQUEST']._serialized_end=2031
  _globals['_GETPOLICYASSIGNMENTRESPONSE']._serialized_start=2033
  _globals['_GETPOLICYASSIGNMENTRESPONSE']._serialized_end=2146
  _globals['_CREATERESOURCEREQUEST']._serialized_start=2148
  _globals['_CREATERESOURCEREQUEST']._serialized_end=2236
  _globals['_CREATERESOURCERESPONSE']._serialized_start=2238
  _globals['_CREATERESOURCERESPONSE']._serialized_end=2262
  _globals['_DELETERESOURCEREQUEST']._serialized_start=2264
  _globals['_DELETERESOURCEREQUEST']._serialized_end=2352
  _globals['_DELETERESOURCERESPONSE']._serialized_start=2354
  _globals['_DELETERESOURCERESPONSE']._serialized_end=2378
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_start=2381
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_end=2613
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_start=2615
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_end=2643
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=2645
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=2714
  _globals['_GETORGANIZATIONRESPONSE']._serialized_start=2716
  _globals['_GETORGANIZATIONRESPONSE']._serialized_end=2741
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_start=2743
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_end=2815
  _globals['_DELETEORGANIZATIONRESPONSE']._serialized_start=2817
  _globals['_DELETEORGANIZATIONRESPONSE']._serialized_end=2845
  _globals['_CREATEPOLICYREQUEST']._serialized_start=2847
  _globals['_CREATEPOLICYREQUEST']._serialized_end=2927
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=2929
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=2951
  _globals['_GETPOLICYREQUEST']._serialized_start=2953
  _globals['_GETPOLICYREQUEST']._serialized_end=3032
  _globals['_GETPOLICYRESPONSE']._serialized_start=3034
  _globals['_GETPOLICYRESPONSE']._serialized_end=3102
  _globals['_DELETEPOLICYREQUEST']._serialized_start=3104
  _globals['_DELETEPOLICYREQUEST']._serialized_end=3186
  _globals['_DELETEPOLICYRESPONSE']._serialized_start=3188
  _globals['_DELETEPOLICYRESPONSE']._serialized_end=3210
  _globals['_LISTPOLICIESREQUEST']._serialized_start=3212
  _globals['_LISTPOLICIESREQUEST']._serialized_end=3269
  _globals['_LISTPOLICIESRESPONSE']._serialized_start=3271
  _globals['_LISTPOLICIESRESPONSE']._serialized_end=3346
  _globals['_CREATEPOLICYBINDINGREQUEST']._serialized_start=3349
  _globals['_CREATEPOLICYBINDINGREQUEST']._serialized_end=3519
  _globals['_CREATEPOLICYBINDINGRESPONSE']._serialized_start=3521
  _globals['_CREATEPOLICYBINDINGRESPONSE']._serialized_end=3550
  _globals['_DELETEPOLICYBINDINGREQUEST']._serialized_start=3553
  _globals['_DELETEPOLICYBINDINGREQUEST']._serialized_end=3723
  _globals['_DELETEPOLICYBINDINGRESPONSE']._serialized_start=3725
  _globals['_DELETEPOLICYBINDINGRESPONSE']._serialized_end=3754
  _globals['_CREATEROLEREQUEST']._serialized_start=3756
  _globals['_CREATEROLEREQUEST']._serialized_end=3828
  _globals['_CREATEROLERESPONSE']._serialized_start=3830
  _globals['_CREATEROLERESPONSE']._serialized_end=3850
  _globals['_GETROLEREQUEST']._serialized_start=3852
  _globals['_GETROLEREQUEST']._serialized_end=3927
  _globals['_GETROLERESPONSE']._serialized_start=3929
  _globals['_GETROLERESPONSE']._serialized_end=3989
  _globals['_DELETEROLEREQUEST']._serialized_start=3991
  _globals['_DELETEROLEREQUEST']._serialized_end=4069
  _globals['_DELETEROLERESPONSE']._serialized_start=4071
  _globals['_DELETEROLERESPONSE']._serialized_end=4091
  _globals['_LISTROLESREQUEST']._serialized_start=4093
  _globals['_LISTROLESREQUEST']._serialized_end=4147
  _globals['_LISTROLESRESPONSE']._serialized_start=4149
  _globals['_LISTROLESRESPONSE']._serialized_end=4213
  _globals['_CREATEROLEACTIONREQUEST']._serialized_start=4216
  _globals['_CREATEROLEACTIONREQUEST']._serialized_end=4367
  _globals['_CREATEROLEACTIONRESPONSE']._serialized_start=4369
  _globals['_CREATEROLEACTIONRESPONSE']._serialized_end=4395
  _globals['_DELETEROLEACTIONREQUEST']._serialized_start=4398
  _globals['_DELETEROLEACTIONREQUEST']._serialized_end=4549
  _globals['_DELETEROLEACTIONRESPONSE']._serialized_start=4551
  _globals['_DELETEROLEACTIONRESPONSE']._serialized_end=4577
# @@protoc_insertion_point(module_scope)



from union.internal.authorizer import definition_pb2 as _definition_pb2
from union.internal.common import authorization_pb2 as _authorization_pb2
from union.internal.common import identifier_pb2 as _identifier_pb2
from union.internal.common import identity_pb2 as _identity_pb2
from union.internal.common import policy_pb2 as _policy_pb2
from union.internal.common import role_pb2 as _role_pb2
from union.internal.validate.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthorizeRequest(_message.Message):
    __slots__ = ["organization", "identity", "resource", "action"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identity: _identity_pb2.Identity
    resource: _authorization_pb2.Resource
    action: _authorization_pb2.Action
    def __init__(self, organization: _Optional[str] = ..., identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ..., resource: _Optional[_Union[_authorization_pb2.Resource, _Mapping]] = ..., action: _Optional[_Union[_authorization_pb2.Action, str]] = ...) -> None: ...

class AuthorizeResponse(_message.Message):
    __slots__ = ["allowed"]
    ALLOWED_FIELD_NUMBER: _ClassVar[int]
    allowed: bool
    def __init__(self, allowed: bool = ...) -> None: ...

class CreateIdentityRequest(_message.Message):
    __slots__ = ["organization", "identity"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identity: _identity_pb2.Identity
    def __init__(self, organization: _Optional[str] = ..., identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ...) -> None: ...

class CreateIdentityResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteIdentityRequest(_message.Message):
    __slots__ = ["organization", "identity"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identity: _identity_pb2.Identity
    def __init__(self, organization: _Optional[str] = ..., identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ...) -> None: ...

class DeleteIdentityResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class AssignIdentityRequest(_message.Message):
    __slots__ = ["organization", "identity", "role_id", "policy_id"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identity: _identity_pb2.Identity
    role_id: _identifier_pb2.RoleIdentifier
    policy_id: _identifier_pb2.PolicyIdentifier
    def __init__(self, organization: _Optional[str] = ..., identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ..., role_id: _Optional[_Union[_identifier_pb2.RoleIdentifier, _Mapping]] = ..., policy_id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ...) -> None: ...

class AssignIdentityResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UnassignIdentityRequest(_message.Message):
    __slots__ = ["organization", "identity", "role_id", "policy_id"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identity: _identity_pb2.Identity
    role_id: _identifier_pb2.RoleIdentifier
    policy_id: _identifier_pb2.PolicyIdentifier
    def __init__(self, organization: _Optional[str] = ..., identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ..., role_id: _Optional[_Union[_identifier_pb2.RoleIdentifier, _Mapping]] = ..., policy_id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ...) -> None: ...

class UnassignIdentityResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetIdentityAssignmentRequest(_message.Message):
    __slots__ = ["identity", "organization"]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    identity: _identity_pb2.Identity
    organization: str
    def __init__(self, identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ..., organization: _Optional[str] = ...) -> None: ...

class GetIdentityAssignmentResponse(_message.Message):
    __slots__ = ["identity_assignment"]
    IDENTITY_ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    identity_assignment: _definition_pb2.IdentityAssignment
    def __init__(self, identity_assignment: _Optional[_Union[_definition_pb2.IdentityAssignment, _Mapping]] = ...) -> None: ...

class ListIdentityAssignmentsRequest(_message.Message):
    __slots__ = ["organization", "identities"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITIES_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identities: _containers.RepeatedCompositeFieldContainer[_identity_pb2.Identity]
    def __init__(self, organization: _Optional[str] = ..., identities: _Optional[_Iterable[_Union[_identity_pb2.Identity, _Mapping]]] = ...) -> None: ...

class ListIdentityAssignmentsResponse(_message.Message):
    __slots__ = ["identity_assignments"]
    IDENTITY_ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    identity_assignments: _containers.RepeatedCompositeFieldContainer[_definition_pb2.IdentityAssignment]
    def __init__(self, identity_assignments: _Optional[_Iterable[_Union[_definition_pb2.IdentityAssignment, _Mapping]]] = ...) -> None: ...

class GetPolicyAssignmentRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.PolicyIdentifier
    def __init__(self, id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ...) -> None: ...

class GetPolicyAssignmentResponse(_message.Message):
    __slots__ = ["policy_assignment"]
    POLICY_ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    policy_assignment: _definition_pb2.PolicyAssignment
    def __init__(self, policy_assignment: _Optional[_Union[_definition_pb2.PolicyAssignment, _Mapping]] = ...) -> None: ...

class CreateResourceRequest(_message.Message):
    __slots__ = ["resource"]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: _authorization_pb2.Resource
    def __init__(self, resource: _Optional[_Union[_authorization_pb2.Resource, _Mapping]] = ...) -> None: ...

class CreateResourceResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteResourceRequest(_message.Message):
    __slots__ = ["resource"]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: _authorization_pb2.Resource
    def __init__(self, resource: _Optional[_Union[_authorization_pb2.Resource, _Mapping]] = ...) -> None: ...

class DeleteResourceResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateOrganizationRequest(_message.Message):
    __slots__ = ["organization", "identity_assignments", "options"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    organization: str
    identity_assignments: _containers.RepeatedCompositeFieldContainer[_definition_pb2.IdentityAssignment]
    options: _definition_pb2.OrganizationOptions
    def __init__(self, organization: _Optional[str] = ..., identity_assignments: _Optional[_Iterable[_Union[_definition_pb2.IdentityAssignment, _Mapping]]] = ..., options: _Optional[_Union[_definition_pb2.OrganizationOptions, _Mapping]] = ...) -> None: ...

class CreateOrganizationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetOrganizationRequest(_message.Message):
    __slots__ = ["organization"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    organization: str
    def __init__(self, organization: _Optional[str] = ...) -> None: ...

class GetOrganizationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteOrganizationRequest(_message.Message):
    __slots__ = ["organization"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    organization: str
    def __init__(self, organization: _Optional[str] = ...) -> None: ...

class DeleteOrganizationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreatePolicyRequest(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class CreatePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetPolicyRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.PolicyIdentifier
    def __init__(self, id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ...) -> None: ...

class GetPolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class DeletePolicyRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.PolicyIdentifier
    def __init__(self, id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ...) -> None: ...

class DeletePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListPoliciesRequest(_message.Message):
    __slots__ = ["organization"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    organization: str
    def __init__(self, organization: _Optional[str] = ...) -> None: ...

class ListPoliciesResponse(_message.Message):
    __slots__ = ["policies"]
    POLICIES_FIELD_NUMBER: _ClassVar[int]
    policies: _containers.RepeatedCompositeFieldContainer[_policy_pb2.Policy]
    def __init__(self, policies: _Optional[_Iterable[_Union[_policy_pb2.Policy, _Mapping]]] = ...) -> None: ...

class CreatePolicyBindingRequest(_message.Message):
    __slots__ = ["policy_id", "binding"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    BINDING_FIELD_NUMBER: _ClassVar[int]
    policy_id: _identifier_pb2.PolicyIdentifier
    binding: _policy_pb2.PolicyBinding
    def __init__(self, policy_id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ..., binding: _Optional[_Union[_policy_pb2.PolicyBinding, _Mapping]] = ...) -> None: ...

class CreatePolicyBindingResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeletePolicyBindingRequest(_message.Message):
    __slots__ = ["policy_id", "binding"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    BINDING_FIELD_NUMBER: _ClassVar[int]
    policy_id: _identifier_pb2.PolicyIdentifier
    binding: _policy_pb2.PolicyBinding
    def __init__(self, policy_id: _Optional[_Union[_identifier_pb2.PolicyIdentifier, _Mapping]] = ..., binding: _Optional[_Union[_policy_pb2.PolicyBinding, _Mapping]] = ...) -> None: ...

class DeletePolicyBindingResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateRoleRequest(_message.Message):
    __slots__ = ["role"]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    role: _role_pb2.Role
    def __init__(self, role: _Optional[_Union[_role_pb2.Role, _Mapping]] = ...) -> None: ...

class CreateRoleResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetRoleRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.RoleIdentifier
    def __init__(self, id: _Optional[_Union[_identifier_pb2.RoleIdentifier, _Mapping]] = ...) -> None: ...

class GetRoleResponse(_message.Message):
    __slots__ = ["role"]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    role: _role_pb2.Role
    def __init__(self, role: _Optional[_Union[_role_pb2.Role, _Mapping]] = ...) -> None: ...

class DeleteRoleRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.RoleIdentifier
    def __init__(self, id: _Optional[_Union[_identifier_pb2.RoleIdentifier, _Mapping]] = ...) -> None: ...

class DeleteRoleResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListRolesRequest(_message.Message):
    __slots__ = ["organization"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    organization: str
    def __init__(self, organization: _Optional[str] = ...) -> None: ...

class ListRolesResponse(_message.Message):
    __slots__ = ["roles"]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[_role_pb2.Role]
    def __init__(self, roles: _Optional[_Iterable[_Union[_role_pb2.Role, _Mapping]]] = ...) -> None: ...

class CreateRoleActionRequest(_message.Message):
    __slots__ = ["id", "action"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.RoleIdentifier
    action: _authorization_pb2.Action
    def __init__(self, id: _Optional[_Union[_identifier_pb2.RoleIdentifier, _Mapping]] = ..., action: _Optional[_Union[_authorization_pb2.Action, str]] = ...) -> None: ...

class CreateRoleActionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteRoleActionRequest(_message.Message):
    __slots__ = ["id", "action"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.RoleIdentifier
    action: _authorization_pb2.Action
    def __init__(self, id: _Optional[_Union[_identifier_pb2.RoleIdentifier, _Mapping]] = ..., action: _Optional[_Union[_authorization_pb2.Action, str]] = ...) -> None: ...

class DeleteRoleActionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Deployment(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNSPECIFIED: _ClassVar[Deployment]
    BYOC: _ClassVar[Deployment]
    SERVERLESS: _ClassVar[Deployment]
UNSPECIFIED: Deployment
BYOC: Deployment
SERVERLESS: Deployment



from common import identifier_pb2 as _identifier_pb2
from union.internal.imagebuilder import definition_pb2 as _definition_pb2
from union.internal.validate.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetImageRequest(_message.Message):
    __slots__ = ["id", "organization", "project_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    id: _definition_pb2.ImageIdentifier
    organization: str
    project_id: _identifier_pb2.ProjectIdentifier
    def __init__(self, id: _Optional[_Union[_definition_pb2.ImageIdentifier, _Mapping]] = ..., organization: _Optional[str] = ..., project_id: _Optional[_Union[_identifier_pb2.ProjectIdentifier, _Mapping]] = ...) -> None: ...

class GetImageResponse(_message.Message):
    __slots__ = ["image"]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    image: _definition_pb2.Image
    def __init__(self, image: _Optional[_Union[_definition_pb2.Image, _Mapping]] = ...) -> None: ...



from ._sglang import DEFAULT_SGLANG_IMAGE, OPTIMIZED_SGLANG_IMAGE, SGLangApp
from ._vllm import DEFAULT_VLLM_IMAGE, OPTIMIZED_VLLM_IMAGE, VLLMApp

__all__ = [
    "DEFAULT_SGLANG_IMAGE",
    "DEFAULT_VLLM_IMAGE",
    "OPTIMIZED_SGLANG_IMAGE",
    "OPTIMIZED_VLLM_IMAGE",
    "SGLangApp",
    "VLLMApp",
]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from union.internal.hooks import payload_pb2 as hooks_dot_payload__pb2


class HooksServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamEvents = channel.unary_stream(
                '/cloudidl.hooks.HooksService/StreamEvents',
                request_serializer=hooks_dot_payload__pb2.StreamEventsRequest.SerializeToString,
                response_deserializer=hooks_dot_payload__pb2.StreamEventsResponse.FromString,
                )
        self.AcknowledgeEvent = channel.unary_unary(
                '/cloudidl.hooks.HooksService/AcknowledgeEvent',
                request_serializer=hooks_dot_payload__pb2.AcknowledgeEventRequest.SerializeToString,
                response_deserializer=hooks_dot_payload__pb2.AcknowledgeEventResponse.FromString,
                )


class HooksServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StreamEvents(self, request, context):
        """StreamEvents streams execution events for the given tenant. Events use the CloudEvents
        format outlined in https://docs.flyte.org/en/latest/deployment/configuration/cloud_event.html.
        See `StreamEventsResponse` for supported events.

        Events are delivered at least once (or until the internal TTL is reached). Events may be
        spread over parallel streams, and the client(s) should be prepared to handle out-of-order events.
        Events will be resent until acknowledged.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcknowledgeEvent(self, request, context):
        """AcknowledgeEvent acknowledges the receipt of an event. Until called, events will be resent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HooksServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamEvents,
                    request_deserializer=hooks_dot_payload__pb2.StreamEventsRequest.FromString,
                    response_serializer=hooks_dot_payload__pb2.StreamEventsResponse.SerializeToString,
            ),
            'AcknowledgeEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgeEvent,
                    request_deserializer=hooks_dot_payload__pb2.AcknowledgeEventRequest.FromString,
                    response_serializer=hooks_dot_payload__pb2.AcknowledgeEventResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cloudidl.hooks.HooksService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HooksService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StreamEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/cloudidl.hooks.HooksService/StreamEvents',
            hooks_dot_payload__pb2.StreamEventsRequest.SerializeToString,
            hooks_dot_payload__pb2.StreamEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcknowledgeEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cloudidl.hooks.HooksService/AcknowledgeEvent',
            hooks_dot_payload__pb2.AcknowledgeEventRequest.SerializeToString,
            hooks_dot_payload__pb2.AcknowledgeEventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
